@@ -7,7 +7,11 @@ if sys.version_info >= (3, 8):
 else:
     import importlib_metadata
 
-from .core import run_validation
+from .core import (
+    autogenerate_validation_steps,
+    run_validation,
+    update_project_validation_steps,
+)
 from .models import (
     Processor,
     ValidationStep,
@@ -33,5 +37,7 @@ __all__ = [
     "Validator",
     "Processor",
     "load_ValidationStep",
+    "autogenerate_validation_steps",
+    "update_project_validation_steps",
     "version",
 ]
