@@ -4,7 +4,8 @@ import logging
 
 from np_lims_tk.core import get_project_asset, put_project_asset
 
-from .dataclasses import (
+from .exceptions import NpValidatorError, ParsingError
+from .models import (
     BuiltinCallable,
     Processor,
     ValidationResult,
@@ -17,7 +18,6 @@ from .dataclasses import (
     load_ValidationStep,
     path_to_ValidationStep,
 )
-from .exceptions import NpValidatorError, ParsingError
 from .path_matching import path_matches_pattern
 
 logger = logging.getLogger(__name__)
